==> owncloud-10.2.0.zip: owncloud/apps/systemtags/l10n/th_TH.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "ป้ายกำกับ",
    "Tagged files" : "ไฟล์ที่ติดแท็ก",
    "Select tags to filter by" : "เลือกแท็กเพื่อกรอง",
    "Please select tags to filter by" : "กรุณาเลือกแท็กเพื่อกรอง",
    "No files found for the selected tags" : "ไม่พบไฟล์แท็กที่เลือก",
    "<strong>System tags</strong> for a file have been modified" : "เมื่อ <strong>แท็กระบบ</strong> ของไฟล์ถูกแก้ไข",
    "You assigned system tag %3$s" : "คุณได้กำหนดแท็กระบบ %3$s แล้ว",
    "%1$s assigned system tag %3$s" : "%1$s ได้ถูกกำหนดแท็กระบบ %3$s",
    "You unassigned system tag %3$s" : "คุณไม่ได้กำหนดแท็กระบบ %3$s แล้ว",
    "%1$s unassigned system tag %3$s" : "%1$s ไม่ได้ถูกกำหนดแท็กระบบ %3$s",
    "You created system tag %2$s" : "คุณได้สร้างแท็กระบบ %2$s แล้ว",
    "%1$s created system tag %2$s" : "%1$s ได้สร้างแท็กระบบ %2$s",
    "You deleted system tag %2$s" : "คุณได้ลบแท็กระบบ %2$s แล้ว",
    "%1$s deleted system tag %2$s" : "%1$s ได้ลบแท็กระบบ %2$s",
    "You updated system tag %3$s to %2$s" : "คุณอัพเดทแท็กระบบจาก %3$s เป็น %2$s",
    "%1$s updated system tag %3$s to %2$s" : "แท็กระบบ %1$s ได้ถูกอัพเดทจาก %3$s เป็น %2$s",
    "You assigned system tag %3$s to %2$s" : "คุณได้กำหนดแท็กระบบจาก %3$s เป็น %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s ได้ถูกกำหนดแท็กระบบ %3$s เป็น %2$s",
    "You unassigned system tag %3$s from %2$s" : "คุณยังไม่ได้ได้กำหนดแท็กระบบจาก %3$s เป็น %2$s",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s ไม่ได้ถูกกำหนดแท็กระบบ %3$s เป็น %2$s",
    "%s (restricted)" : "%s (ถูกจำกัด)",
    "%s (invisible)" : "%s (มองไม่เห็น)",
    "No files in here" : "ไม่มีไฟล์ที่นี่",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Name" : "ชื่อ",
    "Size" : "ขนาด",
    "Modified" : "แก้ไขเมื่อ",
    "%s (static)" : "%s(คงที่) "
},
"nplurals=1; plural=0;");

==> owncloud-10.4.0.zip: owncloud/apps/systemtags/l10n/th_TH.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "ป้ายกำกับ",
    "Tagged files" : "ไฟล์ที่ติดแท็ก",
    "Select tags to filter by" : "เลือกแท็กเพื่อกรอง",
    "Please select tags to filter by" : "กรุณาเลือกแท็กเพื่อกรอง",
    "No files found for the selected tags" : "ไม่พบไฟล์แท็กที่เลือก",
    "<strong>System tags</strong> for a file have been modified" : "เมื่อ <strong>แท็กระบบ</strong> ของไฟล์ถูกแก้ไข",
    "You assigned system tag %3$s" : "คุณได้กำหนดแท็กระบบ %3$s แล้ว",
    "%1$s assigned system tag %3$s" : "%1$s ได้ถูกกำหนดแท็กระบบ %3$s",
    "You unassigned system tag %3$s" : "คุณไม่ได้กำหนดแท็กระบบ %3$s แล้ว",
    "%1$s unassigned system tag %3$s" : "%1$s ไม่ได้ถูกกำหนดแท็กระบบ %3$s",
    "You created system tag %2$s" : "คุณได้สร้างแท็กระบบ %2$s แล้ว",
    "%1$s created system tag %2$s" : "%1$s ได้สร้างแท็กระบบ %2$s",
    "You deleted system tag %2$s" : "คุณได้ลบแท็กระบบ %2$s แล้ว",
    "%1$s deleted system tag %2$s" : "%1$s ได้ลบแท็กระบบ %2$s",
    "You updated system tag %3$s to %2$s" : "คุณอัปเดตแท็กระบบจาก %3$s เป็น %2$s",
    "%1$s updated system tag %3$s to %2$s" : "แท็กระบบ %1$s ได้ถูกอัปเดตจาก %3$s เป็น %2$s",
    "You assigned system tag %3$s to %2$s" : "คุณได้กำหนดแท็กระบบจาก %3$s เป็น %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s ได้ถูกกำหนดแท็กระบบ %3$s เป็น %2$s",
    "You unassigned system tag %3$s from %2$s" : "คุณยังไม่ได้ได้กำหนดแท็กระบบจาก %3$s เป็น %2$s",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s ไม่ได้ถูกกำหนดแท็กระบบ %3$s เป็น %2$s",
    "%s (restricted)" : "%s (ถูกจำกัด)",
    "%s (invisible)" : "%s (มองไม่เห็น)",
    "%s (static)" : "%s(คงที่) ",
    "No files in here" : "ไม่มีไฟล์ที่นี่",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Name" : "ชื่อ",
    "Size" : "ขนาด",
    "Modified" : "แก้ไขเมื่อ"
},
"nplurals=1; plural=0;");
